@@ -1,6 +1,6 @@
 print.rbounds <- function(x, ...) {
   cat("\n", x$msg, "\n")
-  cat(" p-value of estimate .... ", round(x[["pval"]], 4), "\n\n")
+  cat("Unconfounded estimate .... ", round(x[["pval"]], 4), "\n\n")
   print(x$bounds, row.names = FALSE)
   cat("\n", x$note, "\n")
 }
